@@ -20,50 +20,51 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
+
 #include "part.h"
 #include "archivemodel.h"
 #include "archiveview.h"
-#include "infopanel.h"
 #include "arkviewer.h"
+#include "dnddbusinterface.h"
+#include "infopanel.h"
+#include "jobtracker.h"
 #include "kerfuffle/archive.h"
 #include "kerfuffle/extractiondialog.h"
 #include "kerfuffle/jobs.h"
 #include "kerfuffle/settings.h"
-#include "jobtracker.h"
-#include "dnddbusinterface.h"
 
-#include <KPluginFactory>
-#include <KApplication>
 #include <KAboutData>
-#include <KDebug>
 #include <KAction>
-#include <KSelectAction>
 #include <KActionCollection>
-#include <KGuiItem>
-#include <KIcon>
-#include <KTempDir>
-#include <KMessageBox>
-#include <KRun>
-#include <KFileDialog>
+#include <KApplication>
 #include <KConfigGroup>
-#include <KStandardDirs>
-#include <KStandardGuiItem>
-#include <KToggleAction>
+#include <KDebug>
+#include <KFileDialog>
+#include <KGuiItem>
 #include <KIO/Job>
 #include <KIO/NetAccess>
-
-#include <QCursor>
-#include <QAction>
-#include <QSplitter>
-#include <QVBoxLayout>
-#include <QTimer>
-#include <QMenu>
-#include <QMouseEvent>
-#include <QMimeData>
-#include <QtDBus/QtDBus>
+#include <KIcon>
 #include <KInputDialog>
+#include <KMessageBox>
+#include <KPluginFactory>
+#include <KRun>
+#include <KSelectAction>
+#include <KStandardDirs>
+#include <KStandardGuiItem>
+#include <KTempDir>
+#include <KToggleAction>
+
+#include <QAction>
+#include <QCursor>
 #include <QHeaderView>
-#include <QPointer>
+#include <QMenu>
+#include <QMimeData>
+#include <QMouseEvent>
+#include <QSplitter>
+#include <QTimer>
+#include <QVBoxLayout>
+#include <QWeakPointer>
+#include <QtDBus/QtDBus>
 
 using namespace Kerfuffle;
 
@@ -121,9 +122,9 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList& args)
     m_statusBarExtension = new KParts::StatusBarExtension(this);
 
     new DndExtractAdaptor(this);
-    QDBusConnection::sessionBus().registerObject("/DndExtract", this);
+    QDBusConnection::sessionBus().registerObject(QLatin1String( "/DndExtract" ), this);
 
-    setXMLFile("ark_part.rc");
+    setXMLFile(QLatin1String( "ark_part.rc" ));
 }
 
 Part::~Part()
@@ -150,17 +151,22 @@ void Part::registerJob(KJob* job)
 void Part::extractSelectedFilesTo(const QString& localPath)
 {
     kDebug() << "Extract to " << localPath;
-    if (!m_model) return;
+    if (!m_model) {
+        return;
+    }
 
     if (m_view->selectionModel()->selectedRows().count() != 1) {
         m_view->selectionModel()->setCurrentIndex(m_view->currentIndex(), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
     }
-    if (m_view->selectionModel()->selectedRows().count() != 1) return;
+    if (m_view->selectionModel()->selectedRows().count() != 1) {
+        return;
+    }
 
     QVariant internalRoot;
     kDebug() << "valid " << m_view->currentIndex().parent().isValid();
-    if (m_view->currentIndex().parent().isValid())
+    if (m_view->currentIndex().parent().isValid()) {
         internalRoot = m_model->entryForIndex(m_view->currentIndex().parent()).value(InternalID);
+    }
 
     if (internalRoot.isNull()) {
         //we have the special case valid parent, but the parent does not
@@ -172,12 +178,16 @@ void Part::extractSelectedFilesTo(const QString& localPath)
     }
 
     QList<QVariant> files = selectedFilesWithChildren();
-    if (files.isEmpty()) return;
+    if (files.isEmpty()) {
+        return;
+    }
 
     kDebug() << "selected files are " << files;
     Kerfuffle::ExtractionOptions options;
-    options["PreservePaths"] = true;
-    if (!internalRoot.isNull()) options["RootNode"] = internalRoot;
+    options[QLatin1String( "PreservePaths" )] = true;
+    if (!internalRoot.isNull()) {
+        options[QLatin1String("RootNode")] = internalRoot;
+    }
 
     ExtractJob *job = m_model->extractFiles(files, localPath, options);
     registerJob(job);
@@ -210,44 +220,44 @@ void Part::setupView()
 void Part::setupActions()
 {
     KToggleAction *showInfoPanelAction = new KToggleAction(i18nc("@action:inmenu", "Show information panel"), this);
-    actionCollection()->addAction("show-infopanel", showInfoPanelAction);
+    actionCollection()->addAction(QLatin1String( "show-infopanel" ), showInfoPanelAction);
     showInfoPanelAction->setChecked(m_splitter->sizes().at(1) > 0);
     connect(showInfoPanelAction, SIGNAL(triggered(bool)),
             this, SLOT(slotToggleInfoPanel(bool)));
 
     m_saveAsAction = KStandardAction::saveAs(this, SLOT(slotSaveAs()), actionCollection());
 
-    m_previewAction = actionCollection()->addAction("preview");
+    m_previewAction = actionCollection()->addAction(QLatin1String( "preview" ));
     m_previewAction->setText(i18nc("to preview a file inside an archive", "Pre&view"));
-    m_previewAction->setIcon(KIcon("document-preview-archive"));
+    m_previewAction->setIcon(KIcon( QLatin1String( "document-preview-archive" )));
     m_previewAction->setStatusTip(i18n("Click to preview the selected file"));
     connect(m_previewAction, SIGNAL(triggered(bool)),
             this, SLOT(slotPreview()));
 
-    m_extractFilesAction = actionCollection()->addAction("extract");
+    m_extractFilesAction = actionCollection()->addAction(QLatin1String( "extract" ));
     m_extractFilesAction->setText(i18n("E&xtract"));
-    m_extractFilesAction->setIcon(KIcon("archive-extract"));
+    m_extractFilesAction->setIcon(KIcon( QLatin1String( "archive-extract" )));
     m_extractFilesAction->setStatusTip(i18n("Click to open an extraction dialog, where you can choose to extract either all files or just the selected ones"));
-    m_extractFilesAction->setShortcut(QString("Ctrl+E"));
+    m_extractFilesAction->setShortcut(QKeySequence( QLatin1String( "Ctrl+E" ) ));
     connect(m_extractFilesAction, SIGNAL(triggered(bool)),
             this, SLOT(slotExtractFiles()));
 
-    m_addFilesAction = actionCollection()->addAction("add");
-    m_addFilesAction->setIcon(KIcon("archive-insert"));
+    m_addFilesAction = actionCollection()->addAction(QLatin1String( "add" ));
+    m_addFilesAction->setIcon(KIcon( QLatin1String( "archive-insert" )));
     m_addFilesAction->setText(i18n("Add &File..."));
     m_addFilesAction->setStatusTip(i18n("Click to add files to the archive"));
     connect(m_addFilesAction, SIGNAL(triggered(bool)),
             this, SLOT(slotAddFiles()));
 
-    m_addDirAction = actionCollection()->addAction("add-dir");
-    m_addDirAction->setIcon(KIcon("archive-insert-directory"));
+    m_addDirAction = actionCollection()->addAction(QLatin1String( "add-dir" ));
+    m_addDirAction->setIcon(KIcon( QLatin1String( "archive-insert-directory" )));
     m_addDirAction->setText(i18n("Add Fo&lder..."));
     m_addDirAction->setStatusTip(i18n("Click to add a folder to the archive"));
     connect(m_addDirAction, SIGNAL(triggered(bool)),
             this, SLOT(slotAddDir()));
 
-    m_deleteFilesAction = actionCollection()->addAction("delete");
-    m_deleteFilesAction->setIcon(KIcon("archive-remove"));
+    m_deleteFilesAction = actionCollection()->addAction(QLatin1String( "delete" ));
+    m_deleteFilesAction->setIcon(KIcon( QLatin1String( "archive-remove" )));
     m_deleteFilesAction->setText(i18n("De&lete"));
     m_deleteFilesAction->setShortcut(Qt::Key_Delete);
     m_deleteFilesAction->setStatusTip(i18n("Click to delete the selected files"));
@@ -269,55 +279,72 @@ void Part::updateActions()
     m_deleteFilesAction->setEnabled(!isBusy() && (m_view->selectionModel()->selectedRows().count() > 0)
                                     && isWritable);
 
-    QMenu *m = m_extractFilesAction->menu();
-    if (!m) {
-        m = new QMenu(i18n("Recent folders"));
-        m_extractFilesAction->setMenu(m);
-        connect(m, SIGNAL(triggered(QAction*)),
+    QMenu *menu = m_extractFilesAction->menu();
+    if (!menu) {
+        menu = new QMenu;
+        m_extractFilesAction->setMenu(menu);
+        connect(menu, SIGNAL(triggered(QAction*)),
                 this, SLOT(slotQuickExtractFiles(QAction*)));
-        QAction *header = m->addAction(i18n("Quick Extract To..."));
+
+        // Remember to keep this action's properties as similar to
+        // m_extractFilesAction's as possible (except where it does not make
+        // sense, such as the text or the shortcut).
+        QAction *extractTo = menu->addAction(i18n("Extract To..."));
+        extractTo->setIcon(m_extractFilesAction->icon());
+        extractTo->setStatusTip(m_extractFilesAction->statusTip());
+        connect(extractTo, SIGNAL(triggered(bool)), SLOT(slotExtractFiles()));
+
+        menu->addSeparator();
+
+        QAction *header = menu->addAction(i18n("Quick Extract To..."));
         header->setEnabled(false);
-        header->setIcon(KIcon("archive-extract"));
+        header->setIcon(KIcon( QLatin1String( "archive-extract" )));
     }
 
-    while (m->actions().size() > 1) {
-        m->removeAction(m->actions().last());
+    while (menu->actions().size() > 3) {
+        menu->removeAction(menu->actions().last());
     }
 
-    KConfigGroup conf(KGlobal::config(), "DirSelect Dialog");
+    const KConfigGroup conf(KGlobal::config(), "DirSelect Dialog");
     const QStringList dirHistory = conf.readPathEntry("History Items", QStringList());
 
     for (int i = 0; i < qMin(10, dirHistory.size()); ++i) {
-        QAction *newAction = m->addAction(KUrl(dirHistory.at(i)).pathOrUrl());
-        newAction->setData(KUrl(dirHistory.at(i)).pathOrUrl());
+        const KUrl dirUrl(dirHistory.at(i));
+        QAction *newAction = menu->addAction(dirUrl.pathOrUrl());
+        newAction->setData(dirUrl.pathOrUrl());
     }
 }
 
 void Part::slotQuickExtractFiles(QAction *triggeredAction)
 {
-    kDebug() << "Extract to " << triggeredAction->data().toString();
+    // #190507: triggeredAction->data.isNull() means it's the "Extract to..."
+    //          action, and we do not want it to run here
+    if (!triggeredAction->data().isNull()) {
+        kDebug() << "Extract to " << triggeredAction->data().toString();
 
-    const QString userDestination = triggeredAction->data().toString();
-    QString finalDestinationDirectory;
-    const QString detectedSubfolder = detectSubfolder();
+        const QString userDestination = triggeredAction->data().toString();
+        QString finalDestinationDirectory;
+        const QString detectedSubfolder = detectSubfolder();
 
-    if (!isSingleFolderArchive()) {
-        finalDestinationDirectory = userDestination +
-                                    QDir::separator() + detectedSubfolder;
-        QDir(userDestination).mkdir(detectedSubfolder);
-    } else finalDestinationDirectory = userDestination;
+        if (!isSingleFolderArchive()) {
+            finalDestinationDirectory = userDestination +
+                                        QDir::separator() + detectedSubfolder;
+            QDir(userDestination).mkdir(detectedSubfolder);
+        } else {
+            finalDestinationDirectory = userDestination;
+        }
 
-    Kerfuffle::ExtractionOptions options;
-    options["PreservePaths"] = true;
-    QList<QVariant> files = selectedFiles();
-    ExtractJob *job = m_model->extractFiles(files, finalDestinationDirectory, options);
-    registerJob(job);
+        Kerfuffle::ExtractionOptions options;
+        options[QLatin1String( "PreservePaths" )] = true;
+        QList<QVariant> files = selectedFiles();
+        ExtractJob *job = m_model->extractFiles(files, finalDestinationDirectory, options);
+        registerJob(job);
 
-    connect(job, SIGNAL(result(KJob*)),
-            this, SLOT(slotExtractionDone(KJob *)));
-
-    job->start();
+        connect(job, SIGNAL(result(KJob*)),
+                this, SLOT(slotExtractionDone(KJob *)));
 
+        job->start();
+    }
 }
 
 bool Part::isPreviewable(const QModelIndex& index) const
@@ -338,33 +365,43 @@ KAboutData* Part::createAboutData()
 bool Part::openFile()
 {
     const QString localFile(localFilePath());
+    const QFileInfo localFileInfo(localFile);
+    const bool creatingNewArchive =
+        arguments().metaData()[QLatin1String("createNewArchive")] == QLatin1String("true");
 
-    if (arguments().metaData()["createNewArchive"] == "true") {
-        if (QFileInfo(localFile).exists()) {
-            int overwrite =  KMessageBox::questionYesNo(NULL, i18n("The file '%1' already exists. Would you like to open it instead?", localFile), i18nc("@title:window", "File Exists"), KGuiItem(i18n("Open File")), KStandardGuiItem::cancel());
+    if (localFileInfo.isDir()) {
+        KMessageBox::error(NULL, i18nc("@info",
+                                       "<filename>%1</filename> is a directory.",
+                                       localFile));
+        return false;
+    }
 
-            if (overwrite == KMessageBox::No)
+    if (creatingNewArchive) {
+        if (localFileInfo.exists()) {
+            int overwrite =  KMessageBox::questionYesNo(NULL, i18nc("@info", "The archive <filename>%1</filename> already exists. Would you like to open it instead?", localFile), i18nc("@title:window", "File Exists"), KGuiItem(i18n("Open File")), KStandardGuiItem::cancel());
+
+            if (overwrite == KMessageBox::No) {
                 return false;
+            }
         }
     } else {
-        if (!QFileInfo(localFile).exists()) {
-            KMessageBox::sorry(NULL, i18n("Error opening archive: the file '%1' was not found.", localFile), i18nc("@title:window", "Error Opening Archive"));
+        if (!localFileInfo.exists()) {
+            KMessageBox::sorry(NULL, i18nc("@info", "The archive <filename>%1</filename> was not found.", localFile), i18nc("@title:window", "Error Opening Archive"));
             return false;
         }
     }
 
     Kerfuffle::Archive *archive = Kerfuffle::factory(localFile);
 
-    // TODO Post 4.3 string freeze:
-    //      the isReadOnly check must be separate; see addtoarchive.cpp
-    if (!archive || (arguments().metaData()["createNewArchive"] == "true" && archive->isReadOnly())) {
+    if ((!archive) || ((creatingNewArchive) && (archive->isReadOnly()))) {
         QStringList mimeTypeList;
         QHash<QString, QString> mimeTypes;
 
-        if (arguments().metaData()["createNewArchive"] == "true")
+        if (creatingNewArchive) {
             mimeTypeList = Kerfuffle::supportedWriteMimeTypes();
-        else
+        } else {
             mimeTypeList = Kerfuffle::supportedMimeTypes();
+        }
 
         foreach(const QString& mime, mimeTypeList) {
             KMimeType::Ptr mimePtr(KMimeType::mimeType(mime));
@@ -378,21 +415,30 @@ bool Part::openFile()
         mimeComments.sort();
 
         bool ok;
-        QString item(KInputDialog::getItem(i18nc("@title:window", "Unable to Determine Archive Type"),
-                                           i18n("Ark was unable to determine the archive type of the filename.\n\nPlease choose the correct archive type below."),
-                                           mimeComments,
-                                           0,
-                                           false,
-                                           &ok));
+        QString item;
 
-        if (!ok || item.isEmpty())
+        if (creatingNewArchive) {
+            item = KInputDialog::getItem(i18nc("@title:window", "Invalid Archive Type"),
+                                         i18nc("@info", "Ark cannot create archives of the type you have chosen.<nl/><nl/>Please choose another archive type below."),
+                                         mimeComments, 0, false, &ok);
+        } else {
+            item = KInputDialog::getItem(i18nc("@title:window", "Unable to Determine Archive Type"),
+                                         i18nc("@info", "Ark was unable to determine the archive type of the filename.<nl/><nl/>Please choose the correct archive type below."),
+                                         mimeComments,
+                                         0,
+                                         false,
+                                         &ok);
+        }
+
+        if ((!ok) || (item.isEmpty())) {
             return false;
+        }
 
         archive = Kerfuffle::factory(localFile, mimeTypes.key(item));
     }
 
     if (!archive) {
-        KMessageBox::sorry(NULL, i18n("Ark was not able to open the archive '%1'. No library capable of handling the file was found.", localFile), i18nc("@title:window", "Error Opening Archive"));
+        KMessageBox::sorry(NULL, i18nc("@info", "Ark was not able to open the archive <filename>%1</filename>. No plugin capable of handling the file was found.", localFile), i18nc("@title:window", "Error Opening Archive"));
         return false;
     }
 
@@ -401,7 +447,7 @@ bool Part::openFile()
     job->start();
     m_infoPanel->setIndex(QModelIndex());
 
-    if (archive != 0 && arguments().metaData()["showExtractDialog"] == "true") {
+    if (archive != 0 && arguments().metaData()[QLatin1String( "showExtractDialog" )] == QLatin1String( "true" )) {
         QTimer::singleShot(0, this, SLOT(slotExtractFiles()));
     }
 
@@ -426,9 +472,11 @@ void Part::slotLoadingFinished(KJob *job)
 {
     kDebug();
 
-    if (job->error())
-        if (arguments().metaData()["createNewArchive"] != "true")
-            KMessageBox::sorry(NULL, i18n("Reading the archive '%1' failed with the error '%2'", localFilePath(), job->errorText()), i18nc("@title:window", "Error Opening Archive"));
+    if (job->error()) {
+        if (arguments().metaData()[QLatin1String( "createNewArchive" )] != QLatin1String( "true" )) {
+            KMessageBox::sorry(NULL, i18nc("@info", "Loading the archive <filename>%1</filename> failed with the following error: <message>%2</message>", localFilePath(), job->errorText()), i18nc("@title:window", "Error Opening Archive"));
+        }
+    }
 
     m_view->sortByColumn(0, Qt::AscendingOrder);
     m_view->expandToDepth(0);
@@ -486,7 +534,7 @@ void Part::slotPreview(const QModelIndex & index)
 
     if (!entry.isEmpty()) {
         Kerfuffle::ExtractionOptions options;
-        options["PreservePaths"] = true;
+        options[QLatin1String( "PreservePaths" )] = true;
 
         ExtractJob *job = m_model->extractFile(entry[ InternalID ], m_previewDir->name(), options);
         registerJob(job);
@@ -505,7 +553,7 @@ void Part::slotPreviewExtracted(KJob *job)
         const ArchiveEntry& entry =
             m_model->entryForIndex(m_view->selectionModel()->currentIndex());
         const QString fullName =
-            m_previewDir->name() + '/' + entry[ FileName ].toString();
+            m_previewDir->name() + QLatin1Char( '/' ) + entry[ FileName ].toString();
         ArkViewer::view(fullName, widget());
     } else {
         KMessageBox::error(widget(), job->errorString());
@@ -529,38 +577,41 @@ bool Part::isSingleFolderArchive() const
 
 QString Part::detectSubfolder() const
 {
-    if (!m_model) return QString();
+    if (!m_model) {
+        return QString();
+    }
 
     return m_model->archive()->subfolderName();
 }
 
 void Part::slotExtractFiles()
 {
-    kDebug() ;
-    if (!m_model) return;
-
-    QPointer<Kerfuffle::ExtractionDialog> dialog = new Kerfuffle::ExtractionDialog();
-
-    if (m_view->selectionModel()->selectedRows().count() > 0) {
-        dialog->setShowSelectedFiles(true);
+    if (!m_model) {
+        return;
     }
 
-    dialog->setSingleFolderArchive(isSingleFolderArchive());
-    dialog->setSubfolder(detectSubfolder());
+    QWeakPointer<Kerfuffle::ExtractionDialog> dialog = new Kerfuffle::ExtractionDialog;
 
-    dialog->setCurrentUrl(QFileInfo(m_model->archive()->fileName()).path());
+    if (m_view->selectionModel()->selectedRows().count() > 0) {
+        dialog.data()->setShowSelectedFiles(true);
+    }
 
-    if (dialog->exec()) {
+    dialog.data()->setSingleFolderArchive(isSingleFolderArchive());
+    dialog.data()->setSubfolder(detectSubfolder());
+
+    dialog.data()->setCurrentUrl(QFileInfo(m_model->archive()->fileName()).path());
+
+    if (dialog.data()->exec()) {
         //this is done to update the quick extract menu
         updateActions();
 
-        m_destinationDirectory = dialog->destinationDirectory().pathOrUrl();
+        m_destinationDirectory = dialog.data()->destinationDirectory().pathOrUrl();
 
-        QList<QVariant> files;
+        QVariantList files;
 
         //if the user has chosen to extract only selected entries, fetch these
         //from the listview
-        if (!dialog->extractAllFiles()) {
+        if (!dialog.data()->extractAllFiles()) {
             files = selectedFilesWithChildren();
         }
 
@@ -568,8 +619,9 @@ void Part::slotExtractFiles()
 
         Kerfuffle::ExtractionOptions options;
 
-        if (dialog->preservePaths())
-            options["PreservePaths"] = true;
+        if (dialog.data()->preservePaths()) {
+            options[QLatin1String("PreservePaths")] = true;
+        }
 
         ExtractJob *job = m_model->extractFiles(files, m_destinationDirectory, options);
         registerJob(job);
@@ -580,7 +632,7 @@ void Part::slotExtractFiles()
         job->start();
     }
 
-    delete dialog;
+    delete dialog.data();
 }
 
 QList<QVariant> Part::selectedFilesWithChildren()
@@ -590,22 +642,22 @@ QList<QVariant> Part::selectedFilesWithChildren()
     QModelIndexList toIterate = m_view->selectionModel()->selectedRows();
 
     for (int i = 0; i < toIterate.size(); ++i) {
-
         QModelIndex index = toIterate.at(i);
 
         for (int j = 0; j < m_model->rowCount(index); ++j) {
             QModelIndex child = m_model->index(j, 0, index);
-            if (!toIterate.contains(child))
+            if (!toIterate.contains(child)) {
                 toIterate << child;
+            }
         }
-
     }
 
     QVariantList ret;
     foreach(const QModelIndex & index, toIterate) {
         const ArchiveEntry& entry = m_model->entryForIndex(index);
-        if (entry.contains(InternalID))
+        if (entry.contains(InternalID)) {
             ret << entry[ InternalID ];
+        }
     }
     return ret;
 }
@@ -637,7 +689,7 @@ void Part::slotExtractionDone(KJob* job)
             KUrl destinationFolder(m_destinationDirectory);
             destinationFolder.cleanPath();
 
-            KRun::runUrl(destinationFolder, "inode/directory", widget());
+            KRun::runUrl(destinationFolder, QLatin1String( "inode/directory" ), widget());
         }
 
         if (ArkSettings::closeAfterExtraction()) {
@@ -666,21 +718,27 @@ void Part::slotAddFiles(const QStringList& filesToAdd, const QString& path)
     for (int i = 0; i < cleanFilesToAdd.size(); ++i) {
         QString& file = cleanFilesToAdd[i];
         if (QFileInfo(file).isDir()) {
-            if (!file.endsWith('/')) file += '/';
+            if (!file.endsWith(QLatin1Char( '/' ))) {
+                file += QLatin1Char( '/' );
+            }
         }
     }
 
     CompressionOptions options;
 
     QString firstPath = cleanFilesToAdd.first();
-    if (firstPath.right(1) == "/") firstPath.chop(1);
+    if (firstPath.right(1) == QLatin1String( "/" )) {
+        firstPath.chop(1);
+    }
     firstPath = QFileInfo(firstPath).dir().absolutePath();
 
     kDebug() << "Detected relative path to be " << firstPath;
-    options["GlobalWorkDir"] = firstPath;
+    options[QLatin1String( "GlobalWorkDir" )] = firstPath;
 
     AddJob *job = m_model->addFiles(cleanFilesToAdd, options);
-    if (!job) return;
+    if (!job) {
+        return;
+    }
 
     connect(job, SIGNAL(result(KJob*)),
             this, SLOT(slotAddFilesDone(KJob*)));
@@ -690,7 +748,7 @@ void Part::slotAddFiles(const QStringList& filesToAdd, const QString& path)
 
 void Part::slotAddFiles()
 {
-    kDebug() ;
+    kDebug();
     const QStringList filesToAdd = KFileDialog::getOpenFileNames(KUrl("kfiledialog:///ArkAddFiles"), QString(), widget(), i18nc("@title:window", "Add Files"));
 
     slotAddFiles(filesToAdd);
@@ -698,7 +756,7 @@ void Part::slotAddFiles()
 
 void Part::slotAddDir()
 {
-    kDebug() ;
+    kDebug();
     const QString dirToAdd = KFileDialog::getExistingDirectory(KUrl("kfiledialog:///ArkAddFiles"), widget(), i18nc("@title:window", "Add Folder"));
 
     if (!dirToAdd.isEmpty()) {
@@ -708,7 +766,7 @@ void Part::slotAddDir()
 
 void Part::slotAddFilesDone(KJob* job)
 {
-    kDebug() ;
+    kDebug();
     if (job->error()) {
         KMessageBox::error(widget(), job->errorString());
     }
@@ -716,7 +774,7 @@ void Part::slotAddFilesDone(KJob* job)
 
 void Part::slotDeleteFilesDone(KJob* job)
 {
-    kDebug() ;
+    kDebug();
     if (job->error()) {
         KMessageBox::error(widget(), job->errorString());
     }
@@ -724,12 +782,13 @@ void Part::slotDeleteFilesDone(KJob* job)
 
 void Part::slotDeleteFiles()
 {
-    kDebug() ;
+    kDebug();
 
     const int reallyDelete = KMessageBox::questionYesNo(NULL, i18n("Deleting these files is not undoable. Are you sure you want to do this?"), i18nc("@title:window", "Delete files") , KStandardGuiItem::del(), KStandardGuiItem::cancel());
 
-    if (reallyDelete == KMessageBox::No)
+    if (reallyDelete == KMessageBox::No) {
         return;
+    }
 
     DeleteJob *job = m_model->deleteFiles(selectedFilesWithChildren());
     connect(job, SIGNAL(result(KJob*)),
@@ -762,12 +821,12 @@ void Part::slotUpdateSplitterSizes()
 
 void Part::slotSaveAs()
 {
-    KUrl saveUrl = KFileDialog::getSaveUrl(KUrl("kfiledialog:///ArkSaveAs/" + url().fileName()), QString(), widget());
+    KUrl saveUrl = KFileDialog::getSaveUrl(KUrl(QLatin1String( "kfiledialog:///ArkSaveAs/" ) + url().fileName()), QString(), widget());
 
     if ((saveUrl.isValid()) && (!saveUrl.isEmpty())) {
         if (KIO::NetAccess::exists(saveUrl, KIO::NetAccess::DestinationSide, widget())) {
             int overwrite = KMessageBox::warningContinueCancel(widget(),
-                                                               i18n("A file named <b>%1</b> already exists. Are you sure you want to overwrite it?", saveUrl.fileName()),
+                                                               i18nc("@info", "An archive named <filename>%1</filename> already exists. Are you sure you want to overwrite it?", saveUrl.fileName()),
                                                                QString(),
                                                                KStandardGuiItem::overwrite());
 
@@ -781,7 +840,7 @@ void Part::slotSaveAs()
         if (!QFile::exists(localFilePath())) {
             if (url().isLocalFile()) {
                 KMessageBox::error(widget(),
-                                   i18n("The file <b>%1</b> cannot be copied to the specified location. The archive does not exist anymore.", localFilePath()));
+                                   i18nc("@info", "The archive <filename>%1</filename> cannot be copied to the specified location. The archive does not exist anymore.", localFilePath()));
 
                 return;
             } else {
@@ -793,7 +852,7 @@ void Part::slotSaveAs()
 
         if (!KIO::NetAccess::synchronousRun(copyJob, widget())) {
             KMessageBox::error(widget(),
-                               i18n("The archive could not be saved as <b>%1</b>. Try to save it in another location.", saveUrl.pathOrUrl()));
+                               i18nc("@info", "The archive could not be saved as <filename>%1</filename>. Try saving it to another location.", saveUrl.pathOrUrl()));
         }
     }
 }
