@@ -1,6 +1,7 @@
 /*
  * Copyright (c) 2007 Henrique Pinto <henrique.pinto@kdemail.net>
  * Copyright (c) 2008-2009 Harald Hvaal <haraldhv@stud.ntnu.no>
+ * Copyright (c) 2010 Raphael Kubo da Costa <kubito@gmail.com>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -65,12 +66,14 @@ struct LibArchiveInterface::ArchiveWriteCustomDeleter
 };
 
 LibArchiveInterface::LibArchiveInterface(QObject *parent, const QVariantList & args)
-        : ReadWriteArchiveInterface(parent, args),
-        m_cachedArchiveEntryCount(0),
-        m_emitNoEntries(false),
-        m_extractedFilesSize(0),
-        m_workDir(QDir::current())
+    : ReadWriteArchiveInterface(parent, args)
+    , m_cachedArchiveEntryCount(0)
+    , m_emitNoEntries(false)
+    , m_extractedFilesSize(0)
+    , m_workDir(QDir::current())
+    , m_archiveReadDisk(archive_read_disk_new())
 {
+    archive_read_disk_set_standard_lookup(m_archiveReadDisk.data());
 }
 
 LibArchiveInterface::~LibArchiveInterface()
@@ -96,7 +99,7 @@ bool LibArchiveInterface::list()
     }
 
     if (archive_read_open_filename(arch_reader.data(), QFile::encodeName(filename()), 10240) != ARCHIVE_OK) {
-        error(i18n("Could not open the file '%1', libarchive cannot handle it.",
+        error(i18nc("@info", "Could not open the archive <filename>%1</filename>, libarchive cannot handle it.",
                    filename()), QString());
         return false;
     }
@@ -119,27 +122,23 @@ bool LibArchiveInterface::list()
     }
 
     if (result != ARCHIVE_EOF) {
-        error(i18n("The archive reading failed with message: %1",
-                   archive_error_string(arch_reader.data())));
+        error(i18nc("@info", "The archive reading failed with the following error: <message>%1</message>",
+                   QLatin1String( archive_error_string(arch_reader.data()))) );
         return false;
     }
 
-#if (ARCHIVE_API_VERSION>1)
     return archive_read_close(arch_reader.data()) == ARCHIVE_OK;
-#else
-    return true;
-#endif
 }
 
-bool LibArchiveInterface::copyFiles(const QList<QVariant> & files, const QString & destinationDirectory, ExtractionOptions options)
+bool LibArchiveInterface::copyFiles(const QVariantList& files, const QString& destinationDirectory, ExtractionOptions options)
 {
     kDebug() << "Changing current directory to " << destinationDirectory;
     QDir::setCurrent(destinationDirectory);
 
     const bool extractAll = files.isEmpty();
-    const bool preservePaths = options.value("PreservePaths").toBool();
+    const bool preservePaths = options.value(QLatin1String( "PreservePaths" )).toBool();
 
-    const QString rootNode = options.value("RootNode", QVariant()).toString();
+    const QString rootNode = options.value(QLatin1String( "RootNode" ), QVariant()).toString();
     kDebug() << "Set root node" << rootNode;
 
     ArchiveRead arch(archive_read_new());
@@ -157,7 +156,7 @@ bool LibArchiveInterface::copyFiles(const QList<QVariant> & files, const QString
     }
 
     if (archive_read_open_filename(arch.data(), QFile::encodeName(filename()), 10240) != ARCHIVE_OK) {
-        error(i18n("Unable to open the file '%1', libarchive cannot handle it.",
+        error(i18nc("@info", "Could not open the archive <filename>%1</filename>, libarchive cannot handle it.",
                    filename()));
         return false;
     }
@@ -208,7 +207,7 @@ bool LibArchiveInterface::copyFiles(const QList<QVariant> & files, const QString
         //entryName is the name inside the archive, full path
         QString entryName = QDir::fromNativeSeparators(QFile::decodeName(archive_entry_pathname(entry)));
 
-        if (entryName.startsWith('/')) {
+        if (entryName.startsWith(QLatin1Char( '/' ))) {
             //for now we just can't handle absolute filenames in a tar archive.
             //TODO: find out what to do here!!
             error(i18n("This archive contains archive entries with absolute paths, which are not yet supported by ark."));
@@ -293,11 +292,11 @@ bool LibArchiveInterface::copyFiles(const QList<QVariant> & files, const QString
 
             int header_response;
             kDebug() << "Writing " << fileWithoutPath << " to " << archive_entry_pathname(entry);
-            if ((header_response = archive_write_header(writer.data(), entry)) == ARCHIVE_OK)
+            if ((header_response = archive_write_header(writer.data(), entry)) == ARCHIVE_OK) {
                 //if the whole archive is extracted and the total filesize is
                 //available, we use partial progress
                 copyData(arch.data(), writer.data(), (extractAll && m_extractedFilesSize));
-            else if (header_response == ARCHIVE_WARN) {
+            } else if (header_response == ARCHIVE_WARN) {
                 kDebug() << "Warning while writing " << entryName;
             } else {
                 kDebug() << "Writing header failed with error code " << header_response
@@ -317,18 +316,14 @@ bool LibArchiveInterface::copyFiles(const QList<QVariant> & files, const QString
         }
     }
 
-#if (ARCHIVE_API_VERSION>1)
     return archive_read_close(arch.data()) == ARCHIVE_OK;
-#else
-    return true;
-#endif
 }
 
-bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionOptions& options)
+bool LibArchiveInterface::addFiles(const QStringList& files, const CompressionOptions& options)
 {
     const bool creatingNewFile = !QFileInfo(filename()).exists();
-    const QString tempFilename = filename() + ".arkWriting";
-    const QString globalWorkDir = options.value("GlobalWorkDir").toString();
+    const QString tempFilename = filename() + QLatin1String( ".arkWriting" );
+    const QString globalWorkDir = options.value(QLatin1String( "GlobalWorkDir" )).toString();
 
     if (!globalWorkDir.isEmpty()) {
         kDebug() << "GlobalWorkDir is set, changing dir to " << globalWorkDir;
@@ -371,23 +366,23 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
 
     int ret;
     if (creatingNewFile) {
-        if (filename().right(2).toUpper() == "GZ") {
+        if (filename().right(2).toUpper() == QLatin1String( "GZ" )) {
             kDebug() << "Detected gzip compression for new file";
             ret = archive_write_set_compression_gzip(arch_writer.data());
-        } else if (filename().right(3).toUpper() == "BZ2") {
+        } else if (filename().right(3).toUpper() == QLatin1String( "BZ2" )) {
             kDebug() << "Detected bzip2 compression for new file";
             ret = archive_write_set_compression_bzip2(arch_writer.data());
 #ifdef HAVE_LIBARCHIVE_XZ_SUPPORT
-        } else if (filename().right(2).toUpper() == "XZ") {
+        } else if (filename().right(2).toUpper() == QLatin1String( "XZ" )) {
             kDebug() << "Detected xz compression for new file";
             ret = archive_write_set_compression_xz(arch_writer.data());
 #endif
 #ifdef HAVE_LIBARCHIVE_LZMA_SUPPORT
-        } else if (filename().right(4).toUpper() == "LZMA") {
+        } else if (filename().right(4).toUpper() == QLatin1String( "LZMA" )) {
             kDebug() << "Detected lzma compression for new file";
             ret = archive_write_set_compression_lzma(arch_writer.data());
 #endif
-        } else if (filename().right(3).toUpper() == "TAR") {
+        } else if (filename().right(3).toUpper() == QLatin1String( "TAR" )) {
             kDebug() << "Detected no compression for new file (pure tar)";
             ret = archive_write_set_compression_none(arch_writer.data());
         } else {
@@ -396,8 +391,8 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
         }
 
         if (ret != ARCHIVE_OK) {
-            error(i18n("Setting compression failed with the error '%1'",
-                       QString(archive_error_string(arch_writer.data()))));
+            error(i18nc("@info", "Setting the compression method failed with the following error: <message>%1</message>",
+                       QLatin1String(archive_error_string(arch_writer.data()))));
 
             return false;
         }
@@ -423,19 +418,19 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
             ret = archive_write_set_compression_none(arch_writer.data());
             break;
         default:
-            error(i18n("The compression type '%1' is not supported by Ark.", QString(archive_compression_name(arch_reader.data()))));
+            error(i18n("The compression type '%1' is not supported by Ark.", QLatin1String(archive_compression_name(arch_reader.data()))));
             return false;
         }
 
         if (ret != ARCHIVE_OK) {
-            error(i18n("Setting compression failed with the error '%1'", QString(archive_error_string(arch_writer.data()))));
+            error(i18nc("@info", "Setting the compression method failed with the following error: <message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
             return false;
         }
     }
 
     ret = archive_write_open_filename(arch_writer.data(), QFile::encodeName(tempFilename));
     if (ret != ARCHIVE_OK) {
-        error(i18n("Opening the archive for writing failed with error message '%1'", QString(archive_error_string(arch_writer.data()))));
+        error(i18nc("@info", "Opening the archive for writing failed with the following error: <message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
         return false;
     }
 
@@ -446,21 +441,30 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
         success = writeFile(selectedFile, arch_writer.data());
 
         if (!success) {
+            QFile::remove(tempFilename);
             return false;
         }
 
         if (QFileInfo(selectedFile).isDir()) {
-            QDirIterator it(selectedFile, QDir::AllEntries | QDir::Readable | QDir::Hidden | QDir::NoDotAndDotDot, QDirIterator::Subdirectories);
+            QDirIterator it(selectedFile,
+                            QDir::AllEntries | QDir::Readable |
+                            QDir::Hidden | QDir::NoDotAndDotDot,
+                            QDirIterator::Subdirectories);
 
             while (it.hasNext()) {
-                QString path = it.next();
-                if (it.fileName() == ".." || it.fileName() == ".") continue;
+                const QString path = it.next();
+
+                if ((it.fileName() == QLatin1String("..")) ||
+                    (it.fileName() == QLatin1String("."))) {
+                    continue;
+                }
 
                 success = writeFile(path +
-                                    (it.fileInfo().isDir() ? "/" : ""),
+                                    (it.fileInfo().isDir() ? QLatin1String( "/" ) : QLatin1String( "" )),
                                     arch_writer.data());
 
                 if (!success) {
+                    QFile::remove(tempFilename);
                     return false;
                 }
             }
@@ -481,20 +485,19 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
 
             int header_response;
             //kDebug() << "Writing entry " << fn;
-            if ((header_response = archive_write_header(arch_writer.data(), entry)) == ARCHIVE_OK)
+            if ((header_response = archive_write_header(arch_writer.data(), entry)) == ARCHIVE_OK) {
                 //if the whole archive is extracted and the total filesize is
                 //available, we use partial progress
                 copyData(arch_reader.data(), arch_writer.data(), false);
-            else {
+            } else {
                 kDebug() << "Writing header failed with error code " << header_response;
+                QFile::remove(tempFilename);
                 return false;
             }
 
             archive_entry_clear(entry);
         }
-    }
 
-    if (!creatingNewFile) {
         //everything seems OK, so we remove the source file and replace it with
         //the new one.
         //TODO: do some extra checks to see if this is really OK
@@ -506,9 +509,9 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
     return true;
 }
 
-bool LibArchiveInterface::deleteFiles(const QList<QVariant> & files)
+bool LibArchiveInterface::deleteFiles(const QVariantList& files)
 {
-    QString tempFilename = filename() + ".arkWriting";
+    const QString tempFilename = filename() + QLatin1String( ".arkWriting" );
 
     ArchiveRead arch_reader(archive_read_new());
     if (!(arch_reader.data())) {
@@ -560,18 +563,18 @@ bool LibArchiveInterface::deleteFiles(const QList<QVariant> & files)
         ret = archive_write_set_compression_none(arch_writer.data());
         break;
     default:
-        error(i18n("The compression type '%1' is not supported by Ark.", QString(archive_compression_name(arch_reader.data()))));
+        error(i18n("The compression type '%1' is not supported by Ark.", QLatin1String(archive_compression_name(arch_reader.data()))));
         return false;
     }
 
     if (ret != ARCHIVE_OK) {
-        error(i18n("Setting compression failed with the error '%1'", QString(archive_error_string(arch_writer.data()))));
+        error(i18nc("@info", "Setting the compression method failed with the following error: <message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
         return false;
     }
 
     ret = archive_write_open_filename(arch_writer.data(), QFile::encodeName(tempFilename));
     if (ret != ARCHIVE_OK) {
-        error(i18n("Opening the archive for writing failed with error message '%1'", QString(archive_error_string(arch_writer.data()))));
+        error(i18nc("@info", "Opening the archive for writing failed with the following error: <message>%1</message>", QLatin1String(archive_error_string(arch_writer.data()))));
         return false;
     }
 
@@ -633,7 +636,7 @@ void LibArchiveInterface::emitEntryFromArchiveEntry(struct archive_entry *aentry
     e[IsDirectory] = S_ISDIR(archive_entry_mode(aentry));
 
     if (archive_entry_symlink(aentry)) {
-        e[Link] = archive_entry_symlink(aentry);
+        e[Link] = QLatin1String( archive_entry_symlink(aentry) );
     }
 
     e[Timestamp] = QDateTime::fromTime_t(archive_entry_mtime(aentry));
@@ -666,8 +669,9 @@ void LibArchiveInterface::copyData(const QString& filename, struct archive *dest
     ssize_t readBytes;
     QFile file(filename);
 
-    if (!file.open(QIODevice::ReadOnly))
+    if (!file.open(QIODevice::ReadOnly)) {
         return;
+    }
 
     readBytes = file.read(buff, sizeof(buff));
     while (readBytes > 0) {
@@ -712,24 +716,32 @@ void LibArchiveInterface::copyData(struct archive *source, struct archive *dest,
     }
 }
 
+// TODO: if we merge this with copyData(), we can pass more data
+//       such as an fd to archive_read_disk_entry_from_file()
 bool LibArchiveInterface::writeFile(const QString& fileName, struct archive* arch_writer)
 {
-    KDE_struct_stat st;
     int header_response;
 
-    const bool trailingSlash = fileName.endsWith('/');
+    const bool trailingSlash = fileName.endsWith(QLatin1Char( '/' ));
 
     // #191821: workDir must be used instead of QDir::current()
     //          so that symlinks aren't resolved automatically
     // TODO: this kind of call should be moved upwards in the
     //       class hierarchy to avoid code duplication
-    const QString relativeName = m_workDir.relativeFilePath(fileName) + (trailingSlash ? "/" : "");
+    const QString relativeName = m_workDir.relativeFilePath(fileName) + (trailingSlash ? QLatin1String( "/" ) : QLatin1String( "" ));
+
+    // #253059: Even if we use archive_read_disk_entry_from_file,
+    //          libarchive may have been compiled without HAVE_LSTAT,
+    //          or something may have caused it to follow symlinks, in
+    //          which case stat() will be called. To avoid this, we
+    //          call lstat() ourselves.
+    KDE_struct_stat st;
+    KDE_lstat(QFile::encodeName(fileName).constData(), &st);
 
     struct archive_entry *entry = archive_entry_new();
-
-    KDE_stat(QFile::encodeName(relativeName).constData(), &st);
-    archive_entry_copy_stat(entry, &st);
-    archive_entry_copy_pathname(entry, QFile::encodeName(relativeName).constData());
+    archive_entry_set_pathname(entry, QFile::encodeName(relativeName).constData());
+    archive_entry_copy_sourcepath(entry, QFile::encodeName(fileName).constData());
+    archive_read_disk_entry_from_file(m_archiveReadDisk.data(), entry, -1, &st);
 
     kDebug() << "Writing new entry " << archive_entry_pathname(entry);
     if ((header_response = archive_write_header(arch_writer, entry)) == ARCHIVE_OK) {
@@ -740,6 +752,10 @@ bool LibArchiveInterface::writeFile(const QString& fileName, struct archive* arc
         kDebug() << "Writing header failed with error code " << header_response;
         kDebug() << "Error while writing..." << archive_error_string(arch_writer) << "(error nb =" << archive_errno(arch_writer) << ')';
 
+        error(i18nc("@info Error in a message box",
+                    "Ark could not compress <filename>%1</filename>:<nl/>%2",
+                    fileName, archive_error_string(arch_writer)));
+
         archive_entry_free(entry);
 
         return false;
