@@ -1,11 +1,7 @@
-/***************************************************************************
-                          kgpginterface.cpp  -  description
-                             -------------------
-    begin                : Mon Jul 8 2002
-    copyright          : (C) 2002 by Jean-Baptiste Mardelle
-    email                : bj@altern.org
- ***************************************************************************/
-
+/*
+ * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
+ * Copyright (C) 2007,2008,2009,2010 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ */
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,8 +14,10 @@
 #include "kgpginterface.h"
 
 #include <QDir>
-#include <QTextStream>
 #include <QFile>
+#include <QPixmap>
+#include <QString>
+#include <QTextStream>
 
 #include <kio/netaccess.h>
 #include <KMessageBox>
@@ -37,10 +35,17 @@
 #include "kgpgsettings.h"
 #include "convert.h"
 #include "gpgproc.h"
+#include "core/KGpgKeyNode.h"
+#include "core/KGpgSignNode.h"
+#include "core/KGpgSubkeyNode.h"
+#include "core/KGpgUatNode.h"
+#include "core/KGpgUidNode.h"
 
 using namespace KgpgCore;
 
 KgpgInterface::KgpgInterface()
+	: m_readNode(NULL),
+	m_currentSNode(NULL)
 {
 }
 
@@ -53,7 +58,7 @@ int KgpgInterface::gpgVersion(const QString &vstr)
 	if (vstr.isEmpty())
 		return -1;
 
-	QStringList values(vstr.split('.'));
+	QStringList values(vstr.split(QLatin1Char( '.' )));
 	if (values.count() < 3)
 		return -2;
 
@@ -63,7 +68,7 @@ int KgpgInterface::gpgVersion(const QString &vstr)
 QString KgpgInterface::gpgVersionString(const QString &binary)
 {
 	GPGProc process(0, binary);
-	process << "--version";
+	process << QLatin1String( "--version" );
 	process.start();
 	process.waitForFinished(-1);
 
@@ -72,7 +77,7 @@ QString KgpgInterface::gpgVersionString(const QString &binary)
 
 	QString line;
 	if (process.readln(line) != -1)
-		return line.simplified().section(' ', -1);
+		return line.simplified().section(QLatin1Char( ' ' ), -1);
 	else
 		return QString();
 }
@@ -80,7 +85,7 @@ QString KgpgInterface::gpgVersionString(const QString &binary)
 QString KgpgInterface::getGpgProcessHome(const QString &binary)
 {
 	GPGProc process(0, binary);
-	process << "--version";
+	process << QLatin1String( "--version" );
 	process.start();
 	process.waitForFinished(-1);
 
@@ -106,7 +111,7 @@ QString KgpgInterface::getGpgHome(const QString &binary)
 	QByteArray env(qgetenv("GNUPGHOME"));
 	QString gpgHome;
 	if (!env.isEmpty()) {
-		gpgHome = env;
+		gpgHome = QLatin1String( env );
 	} else if (!binary.isEmpty()) {
 		// Second try: start GnuPG and ask what it is
 		gpgHome = getGpgProcessHome(binary);
@@ -115,19 +120,19 @@ QString KgpgInterface::getGpgHome(const QString &binary)
 	// Third try: guess what it is.
 	if (gpgHome.isEmpty()) {
 #ifdef Q_OS_WIN32	//krazy:exclude=cpp
-		gpgHome = qgetenv("APPDATA") + "/gnupg/";
-		gpgHome.replace('\\', '/');
+		gpgHome = qgetenv("APPDATA") + QLatin1String( "/gnupg/" );
+		gpgHome.replace(QLatin1Char( '\\' ), QLatin1Char( '/' ));
 #else
-		gpgHome = QDir::homePath() + "/.gnupg/";
+		gpgHome = QDir::homePath() + QLatin1String( "/.gnupg/" );
 #endif
 	}
 
-	gpgHome.replace("//", "/");
+	gpgHome.replace(QLatin1String( "//" ), QLatin1String( "/" ));
 
-	if (!gpgHome.endsWith('/'))
-		gpgHome.append('/');
+	if (!gpgHome.endsWith(QLatin1Char( '/' )))
+		gpgHome.append(QLatin1Char( '/' ));
 
-	if (gpgHome.startsWith('~'))
+	if (gpgHome.startsWith(QLatin1Char( '~' )))
 		gpgHome.replace(0, 1, QDir::homePath());
 
 	KStandardDirs::makeDir(gpgHome, 0700);
@@ -145,7 +150,7 @@ QStringList KgpgInterface::getGpgGroupNames(const QString &configfile)
 			QString result(t.readLine().simplified());
 			if (result.startsWith(QLatin1String("group "))) {
 				result.remove(0, 6);
-				groups.append(result.section('=', 0, 0).simplified());
+				groups.append(result.section(QLatin1Char( '=' ), 0, 0).simplified());
 			}
 		}
 		qfile.close();
@@ -166,9 +171,9 @@ QStringList KgpgInterface::getGpgGroupSetting(const QString &name, const QString
 				result.remove(0, 6);
 				if (result.simplified().startsWith(name)) {
 					kDebug(2100) << "Found group: " << name;
-					result = result.section('=', 1);
-					result = result.section('#', 0, 0);
-					return result.split(' ', QString::SkipEmptyParts);
+					result = result.section(QLatin1Char( '=' ), 1);
+					result = result.section(QLatin1Char( '#' ), 0, 0);
+					return result.split(QLatin1Char( ' ' ), QString::SkipEmptyParts);
 				}
 			}
 		}
@@ -181,7 +186,7 @@ void KgpgInterface::setGpgGroupSetting(const QString &name, const QStringList &v
 {
 	QFile qfile(configfile);
 
-	kDebug(2100) << "Changing group: " << name ;
+	kDebug(2100) << "Changing group: " << name;
 	if (qfile.open(QIODevice::ReadOnly) && (qfile.exists())) {
 		QTextStream t(&qfile);
 		QString texttowrite;
@@ -193,17 +198,17 @@ void KgpgInterface::setGpgGroupSetting(const QString &name, const QStringList &v
 
 			if (result2.startsWith(QLatin1String("group "))) {
 				result2 = result2.remove(0, 6).simplified();
-				if (result2.startsWith(name) && (result2.remove(0, name.length()).simplified().startsWith('='))) {
-					result = QString("group %1=%2").arg(name).arg(values.join(QString(' ')));
+				if (result2.startsWith(name) && (result2.remove(0, name.length()).simplified().startsWith(QLatin1Char( '=' )))) {
+                                    result = QString::fromLatin1("group %1=%2").arg(name).arg(values.join(QLatin1String( " " )));
 					found = true;
 				}
 			}
-			texttowrite += result + '\n';
+			texttowrite += result + QLatin1Char( '\n' );
 		}
 		qfile.close();
 
 		if (!found)
-			texttowrite += '\n' + QString("group %1=%2").arg(name).arg(values.join(" "));
+                    texttowrite += QLatin1Char( '\n' ) + QString::fromLatin1("group %1=%2").arg(name).arg(values.join( QLatin1String( " " )));
 
 		if (qfile.open(QIODevice::WriteOnly)) {
 			QTextStream t(&qfile);
@@ -213,6 +218,49 @@ void KgpgInterface::setGpgGroupSetting(const QString &name, const QStringList &v
 	}
 }
 
+bool KgpgInterface::renameGroup(const QString &oldName, const QString &newName, const QString &configfile)
+{
+	QFile qfile(configfile);
+
+	kDebug(2100) << "Renaming group " << oldName << " to " << newName;
+	if (qfile.open(QIODevice::ReadOnly) && (qfile.exists())) {
+		QTextStream t(&qfile);
+		QString texttowrite;
+		bool found = false;
+
+		while (!t.atEnd()) {
+			QString result = t.readLine();
+			QString result2 = result.simplified();
+
+			if (result2.startsWith(QLatin1String("group "))) {
+				result2 = result2.remove(0, 6).simplified();
+				if (result2.startsWith(oldName)) {
+					QString values = result2.remove(0, oldName.length()).simplified();
+					found = values.startsWith(QLatin1Char( '=' ));
+					if (found) {
+						result = QLatin1String("group ") + newName + QLatin1Char( ' ' ) + values;
+					}
+				}
+			}
+			texttowrite += result + QLatin1Char( '\n' );
+		}
+		qfile.close();
+
+		if (!found) {
+			kDebug(2100) << "Group " << oldName << " not renamed, group does not exist";
+			return false;
+		}
+
+		if (qfile.open(QIODevice::WriteOnly)) {
+			QTextStream t(&qfile);
+			t << texttowrite;
+			qfile.close();
+			return true;
+		}
+	}
+	return false;
+}
+
 void KgpgInterface::delGpgGroup(const QString &name, const QString &configfile)
 {
 	QFile qfile(configfile);
@@ -227,11 +275,11 @@ void KgpgInterface::delGpgGroup(const QString &name, const QString &configfile)
 
 			if (result2.startsWith(QLatin1String("group "))) {
 				result2 = result2.remove(0, 6).simplified();
-				if (result2.startsWith(name) && (result2.remove(0, name.length()).simplified().startsWith('=')))
+				if (result2.startsWith(name) && (result2.remove(0, name.length()).simplified().startsWith(QLatin1Char( '=' ))))
 					continue;
 			}
 
-			texttowrite += result + '\n';
+			texttowrite += result + QLatin1Char( '\n' );
 		}
 
 		qfile.close();
@@ -246,7 +294,7 @@ void KgpgInterface::delGpgGroup(const QString &name, const QString &configfile)
 
 QString KgpgInterface::getGpgSetting(const QString &name, const QString &configfile)
 {
-	const QString tmp(name.simplified() + ' ');
+	const QString tmp(name.simplified() + QLatin1Char( ' ' ));
 	QFile qfile(configfile);
 
 	if (qfile.open(QIODevice::ReadOnly) && (qfile.exists())) {
@@ -255,7 +303,7 @@ QString KgpgInterface::getGpgSetting(const QString &name, const QString &configf
 			QString result(t.readLine().simplified());
 			if (result.startsWith(tmp)) {
 				result = result.mid(tmp.length()).simplified();
-				return result.section(' ', 0, 0);
+				return result.section(QLatin1Char( ' ' ), 0, 0);
 			}
 		}
 		qfile.close();
@@ -269,7 +317,7 @@ void KgpgInterface::setGpgSetting(const QString &name, const QString &value, con
 	QFile qfile(url);
 
 	if (qfile.open(QIODevice::ReadOnly) && (qfile.exists())) {
-		const QString temp(name + ' ');
+		const QString temp(name + QLatin1Char( ' ' ));
 		QString texttowrite;
 		bool found = false;
 		QTextStream t(&qfile);
@@ -278,18 +326,18 @@ void KgpgInterface::setGpgSetting(const QString &name, const QString &value, con
 			QString result = t.readLine();
 			if (result.simplified().startsWith(temp)) {
 				if (!value.isEmpty())
-					result = temp + ' ' + value;
+					result = temp + QLatin1Char( ' ' ) + value;
 				else
 					result.clear();
 				found = true;
 			}
 
-			texttowrite += result + '\n';
+			texttowrite += result + QLatin1Char( '\n' );
 		}
 
 		qfile.close();
 		if ((!found) && (!value.isEmpty()))
-			texttowrite += '\n' + temp + ' ' + value;
+			texttowrite += QLatin1Char( '\n' ) + temp + QLatin1Char( ' ' ) + value;
 
 		if (qfile.open(QIODevice::WriteOnly)) {
 			QTextStream t(&qfile);
@@ -334,7 +382,7 @@ void KgpgInterface::setGpgBoolSetting(const QString &name, const bool enable, co
 				found = true;
 			}
 
-			texttowrite += result + '\n';
+			texttowrite += result + QLatin1Char( '\n' );
 		}
 		qfile.close();
 
@@ -373,19 +421,14 @@ int KgpgInterface::sendPassphrase(const QString &text, KProcess *process, const
 	return 0;
 }
 
-KgpgKeyList KgpgInterface::readPublicKeys(const bool block, const QStringList &ids, const bool withsigs)
+KgpgKeyList KgpgInterface::readPublicKeys(const bool block, const QStringList &ids)
 {
-	m_publiclistkeys = KgpgKeyList();
+	m_publiclistkeys.clear();
 	m_publickey = KgpgKey();
 	m_numberid = 0;
-	cycle = "none";
 
 	GPGProc *process = new GPGProc(this);
-	*process << "--with-colons" << "--with-fingerprint" << "--fixed-list-mode";
-	if (withsigs)
-		*process << "--list-sigs";
-	else
-		*process << "--list-keys";
+	*process << QLatin1String( "--with-colons" ) << QLatin1String( "--with-fingerprint" ) << QLatin1String( "--fixed-list-mode" ) << QLatin1String( "--list-keys" );
 
 	*process << ids;
 	process->setOutputChannelMode(KProcess::MergedChannels);
@@ -404,6 +447,28 @@ KgpgKeyList KgpgInterface::readPublicKeys(const bool block, const QStringList &i
 	}
 }
 
+KgpgCore::KgpgKey KgpgInterface::readSignatures(KGpgKeyNode *node)
+{
+	m_readNode = node;
+
+	m_publiclistkeys.clear();
+	m_publickey = KgpgKey();
+	m_numberid = 0;
+
+	GPGProc *process = new GPGProc(this);
+	*process << QLatin1String( "--with-colons" ) << QLatin1String( "--with-fingerprint" ) << QLatin1String( "--fixed-list-mode" ) << QLatin1String( "--list-sigs" );
+
+	*process << node->getId();
+	process->setOutputChannelMode(KProcess::MergedChannels);
+
+	process->start();
+	process->waitForFinished(-1);
+	readPublicKeysProcess(process);
+	readPublicKeysFin(process, true);
+
+	return m_publiclistkeys.first();
+}
+
 void KgpgInterface::readPublicKeysProcess(GPGProc *p)
 {
 	QStringList lsp;
@@ -412,11 +477,9 @@ void KgpgInterface::readPublicKeysProcess(GPGProc *p)
 		p = qobject_cast<GPGProc *>(sender());
 
 	while ((items = p->readln(lsp)) >= 0) {
-		if ((lsp.at(0) == "pub") && (items >= 10)) {
-			if (cycle != "none") {
-				cycle = "none";
+		if ((lsp.at(0) == QLatin1String( "pub" )) && (items >= 10)) {
+			if (!m_publickey.name().isEmpty())
 				m_publiclistkeys << m_publickey;
-			}
 
 			m_publickey = KgpgKey();
 
@@ -432,16 +495,14 @@ void KgpgInterface::readPublicKeysProcess(GPGProc *p)
 			else
 				m_publickey.setExpiration(QDateTime::fromTime_t(lsp.at(6).toUInt()));
 
-			m_publickey.setValid((items <= 11) || !lsp.at(11).contains('D', Qt::CaseSensitive));  // disabled key
-
-			cycle = "pub";
+			m_publickey.setValid((items <= 11) || !lsp.at(11).contains(QLatin1Char( 'D' ), Qt::CaseSensitive));  // disabled key
 
 			m_numberid = 0;
-		} else if ((lsp.at(0) == "fpr") && (items >= 10)) {
+		} else if ((lsp.at(0) == QLatin1String( "fpr" )) && (items >= 10)) {
 			const QString fingervalue(lsp.at(9));
 
 			m_publickey.setFingerprint(fingervalue);
-		} else if ((lsp.at(0) == "sub") && (items >= 7)) {
+		} else if ((lsp.at(0) == QLatin1String( "sub" )) && (items >= 7)) {
 			KgpgKeySub sub;
 
 			sub.setId(lsp.at(4).right(8));
@@ -454,15 +515,15 @@ void KgpgInterface::readPublicKeysProcess(GPGProc *p)
 			if (items <= 11) {
 				sub.setValid(true);
 			} else {
-				sub.setValid(!lsp.at(11).contains('D'));
+				sub.setValid(!lsp.at(11).contains(QLatin1Char( 'D' )));
 
-				if (lsp.at(11).contains('s'))
+				if (lsp.at(11).contains(QLatin1Char( 's' )))
 					sub.setType(sub.type() | SKT_SIGNATURE);
-				if (lsp.at(11).contains('e'))
+				if (lsp.at(11).contains(QLatin1Char( 'e' )))
 					sub.setType(sub.type() | SKT_ENCRYPTION);
-				if (lsp.at(11).contains('e'))
+				if (lsp.at(11).contains(QLatin1Char( 'e' )))
 					sub.setType(sub.type() | SKT_AUTHENTICATION);
-				if (lsp.at(11).contains('e'))
+				if (lsp.at(11).contains(QLatin1Char( 'e' )))
 					sub.setType(sub.type() | SKT_CERTIFICATION);
 			}
 
@@ -472,88 +533,63 @@ void KgpgInterface::readPublicKeysProcess(GPGProc *p)
 				sub.setExpiration(QDateTime::fromTime_t(lsp.at(6).toUInt()));
 
 			m_publickey.subList()->append(sub);
-			cycle = "sub";
-		} else if (lsp.at(0) == "uat") {
+			if (m_readNode == NULL)
+				m_currentSNode = NULL;
+			else
+				m_currentSNode = new KGpgSubkeyNode(m_readNode, sub);
+		} else if (lsp.at(0) == QLatin1String( "uat" )) {
 			m_numberid++;
-			KgpgKeyUat uat;
-			uat.setId(QString::number(m_numberid));
-			uat.setCreation(QDateTime::fromTime_t(lsp.at(5).toUInt()));
-			m_publickey.uatList()->append(uat);
-
-			cycle = "uat";
-		} else if ((lsp.at(0) == "uid") && (items >= 10)) {
-			QString fullname(lsp.at(9));
-			QString kmail;
-			if (fullname.contains('<') ) {
-				kmail = fullname;
-
-				if (fullname.contains(')') )
-					kmail = kmail.section(')', 1);
-
-				kmail = kmail.section('<', 1);
-				kmail.truncate(kmail.length() - 1);
-
-				if (kmail.contains('<')) {
-					// several email addresses in the same key
-					kmail = kmail.replace('>', ';');
-					kmail.remove('<');
-				}
+			if (m_readNode != NULL) {
+				m_currentSNode = new KGpgUatNode(m_readNode, m_numberid, lsp);
 			}
-
-			QString kname(fullname.section(" <", 0, 0));
-			QString comment;
-			if (fullname.contains('(') ) {
-				kname = kname.section(" (", 0, 0);
-				comment = fullname.section('(', 1, 1);
-				comment = comment.section(')', 0, 0);
-			}
-
+		} else if ((lsp.at(0) == QLatin1String( "uid" )) && (items >= 10)) {
 			if (m_numberid == 0) {
+				QString fullname(lsp.at(9));
+				QString kmail;
+				if (fullname.contains(QLatin1Char( '<' )) ) {
+					kmail = fullname;
+
+					if (fullname.contains(QLatin1Char( ')' )) )
+						kmail = kmail.section(QLatin1Char( ')' ), 1);
+
+					kmail = kmail.section(QLatin1Char( '<' ), 1);
+					kmail.truncate(kmail.length() - 1);
+
+					if (kmail.contains(QLatin1Char( '<' ))) {
+						// several email addresses in the same key
+						kmail = kmail.replace(QLatin1Char( '>' ), QLatin1Char( ';' ));
+						kmail.remove(QLatin1Char( '<' ));
+					}
+				}
+
+				QString kname(fullname.section( QLatin1String( " <" ), 0, 0));
+				QString comment;
+				if (fullname.contains(QLatin1Char( '(' )) ) {
+					kname = kname.section( QLatin1String( " (" ), 0, 0);
+					comment = fullname.section(QLatin1Char( '(' ), 1, 1);
+					comment = comment.section(QLatin1Char( ')' ), 0, 0);
+				}
+
 				m_numberid++;
 				m_publickey.setEmail(kmail);
 				m_publickey.setComment(comment);
 				m_publickey.setName(kname);
+
+				m_currentSNode = m_readNode;
 			} else {
-				KgpgKeyUid uid;
-
-				uid.setEmail(kmail);
-				uid.setComment(comment);
-				uid.setName(kname);
-				uid.setTrust(Convert::toTrust(lsp.at(1)));
-				uid.setValid((items <= 11) || !lsp.at(11).contains('D'));
-
-				uid.setIndex(++m_numberid);
-
-				m_publickey.uidList()->append(uid);
-
-				cycle = "uid";
+				m_numberid++;
+				if (m_readNode != NULL) {
+					m_currentSNode = new KGpgUidNode(m_readNode, m_numberid, lsp);
+				}
 			}
-		} else if (((lsp.at(0) == "sig") || (lsp.at(0) == "rev")) && (items >= 11)) {
-			KgpgKeySign signature;
+		} else if (((lsp.at(0) == QLatin1String( "sig" )) || (lsp.at(0) == QLatin1String( "rev" ))) && (items >= 11)) {
+			// there are no strings here that could have a recoded QLatin1Char( ':' ) in them
+			const QString signature = lsp.join(QLatin1String(":"));
 
-			signature.setId(lsp.at(4));
-			signature.setCreation(QDateTime::fromTime_t(lsp.at(5).toUInt()));
-
-			if (lsp.at(6).isEmpty())
-				signature.setExpiration(QDateTime());
-			else
-				signature.setExpiration(QDateTime::fromTime_t(lsp.at(6).toUInt()));
-
-			if (lsp.at(10).endsWith('l'))
-				signature.setLocal(true);
-
-			signature.setRevocation(lsp.at(0) == "rev");
-
-			if (cycle == "pub")
-				m_publickey.addSign(signature);
-			else if (cycle == "uat")
-				m_publickey.uatList()->last().addSign(signature);
-			else if (cycle == "uid")
-				m_publickey.uidList()->last().addSign(signature);
-			else if (cycle == "sub")
-				m_publickey.subList()->last().addSign(signature);
+			if (m_currentSNode != NULL)
+				(void) new KGpgSignNode(m_currentSNode, lsp);
 		} else {
-			log += lsp.join(QString(':')) + '\n';
+			log += lsp.join(QString(QLatin1Char( ':' ))) + QLatin1Char( '\n' );
 		}
 	}
 }
@@ -564,7 +600,7 @@ void KgpgInterface::readPublicKeysFin(GPGProc *p, const bool block)
 		p = qobject_cast<GPGProc *>(sender());
 
 	// insert the last key
-	if (cycle != "none")
+	if (!m_publickey.name().isEmpty())
 		m_publiclistkeys << m_publickey;
 
 	if (p->exitCode() != 0) {
@@ -585,7 +621,7 @@ KgpgKeyList KgpgInterface::readSecretKeys(const QStringList &ids)
 	m_secretactivate = false;
 
 	GPGProc *process = new GPGProc(this);
-	*process << "--with-colons" << "--list-secret-keys" << "--with-fingerprint" << "--fixed-list-mode";
+	*process << QLatin1String( "--with-colons" ) << QLatin1String( "--list-secret-keys" ) << QLatin1String( "--with-fingerprint" ) << QLatin1String( "--fixed-list-mode" );
 
 	*process << ids;
 
@@ -608,7 +644,7 @@ void KgpgInterface::readSecretKeysProcess(GPGProc *p)
 	bool hasuid = true;
 
 	while ( (items = p->readln(lsp)) >= 0 ) {
-		if ((lsp.at(0) == "sec") && (items >= 10)) {
+		if ((lsp.at(0) == QLatin1String( "sec" )) && (items >= 10)) {
 			if (m_secretactivate)
 			m_secretlistkeys << m_secretkey;
 
@@ -627,25 +663,25 @@ void KgpgInterface::readSecretKeysProcess(GPGProc *p)
 			else
 				m_secretkey.setExpiration(QDateTime::fromTime_t(lsp.at(6).toUInt()));
 			hasuid = true;
-		} else if ((lsp.at(0) == "uid") && (items >= 10)) {
+		} else if ((lsp.at(0) == QLatin1String( "uid" )) && (items >= 10)) {
 			if (hasuid)
 				continue;
 
 			hasuid = true;
 
 			const QString fullname(lsp.at(9));
-			if (fullname.contains('<' )) {
+			if (fullname.contains(QLatin1Char( '<' ) )) {
 				QString kmail(fullname);
 
-				if (fullname.contains(')' ))
-					kmail = kmail.section(')', 1);
+				if (fullname.contains(QLatin1Char( ')' ) ))
+					kmail = kmail.section(QLatin1Char( ')' ), 1);
 
-				kmail = kmail.section('<', 1);
+				kmail = kmail.section(QLatin1Char( '<' ), 1);
 				kmail.truncate(kmail.length() - 1);
 
-				if (kmail.contains('<' )) { // several email addresses in the same key
-					kmail = kmail.replace('>', ';');
-					kmail.remove('<');
+				if (kmail.contains(QLatin1Char( '<' ) )) { // several email addresses in the same key
+					kmail = kmail.replace(QLatin1Char( '>' ), QLatin1Char( ';' ));
+					kmail.remove(QLatin1Char( '<' ));
 				}
 
 				m_secretkey.setEmail(kmail);
@@ -653,18 +689,18 @@ void KgpgInterface::readSecretKeysProcess(GPGProc *p)
 				m_secretkey.setEmail(QString());
 			}
 
-			QString kname(fullname.section(" <", 0, 0));
-			if (fullname.contains('(' )) {
-				kname = kname.section(" (", 0, 0);
-				QString comment = fullname.section('(', 1, 1);
-				comment = comment.section(')', 0, 0);
+			QString kname(fullname.section( QLatin1String( " <" ), 0, 0));
+			if (fullname.contains(QLatin1Char( '(' ) )) {
+				kname = kname.section( QLatin1String( " (" ), 0, 0);
+				QString comment = fullname.section(QLatin1Char( '(' ), 1, 1);
+				comment = comment.section(QLatin1Char( ')' ), 0, 0);
 
 				m_secretkey.setComment(comment);
 			} else {
 				m_secretkey.setComment(QString());
 			}
 			m_secretkey.setName(kname);
-		} else if ((lsp.at(0) == "fpr") && (items >= 10)) {
+		} else if ((lsp.at(0) == QLatin1String( "fpr" )) && (items >= 10)) {
 			const QString fingervalue(lsp.at(9));
 
 			m_secretkey.setFingerprint(fingervalue);
@@ -672,86 +708,35 @@ void KgpgInterface::readSecretKeysProcess(GPGProc *p)
 	}
 }
 
-KgpgCore::KgpgKeyList
-KgpgInterface::readJoinedKeys(const KgpgCore::KgpgKeyTrust trust, const QStringList &ids)
-{
-	KgpgKeyList secretkeys = readSecretKeys(ids);
-	KgpgKeyList publickeys = readPublicKeys(true, ids, false);
-	int i, j;
-
-	for (i = publickeys.size() - 1; i >= 0; i--)
-		if (publickeys.at(i).trust() < trust)
-			publickeys.removeAt(i);
-
-	foreach (const KgpgKey &seckey, secretkeys) {
-		for (j = 0; j < publickeys.size(); j++)
-			if (seckey.fullId() == publickeys.at(j).fullId()) {
-				publickeys[j].setSecret(true);
-				break;
-			}
-	}
-
-	// move the secret keys to the top of the list
-	for (j = 1; j < publickeys.size(); j++)
-		if (publickeys.at(j).secret())
-			publickeys.move(j, 0);
-
-	return publickeys;
-}
-
-QPixmap KgpgInterface::loadPhoto(const QString &keyid, const QString &uid, const bool block)
+QPixmap KgpgInterface::loadPhoto(const QString &keyid, const QString &uid)
 {
 #ifdef Q_OS_WIN32	//krazy:exclude=cpp
-	const QString pgpgoutput("cmd /C \"echo %I\"");
+	const QString pgpgoutput = QLatin1String("cmd /C \"echo %I\"");
 #else
-	const QString pgpgoutput("echo %I");
+	const QString pgpgoutput = QLatin1String("echo %I");
 #endif
 
-	KProcess *workProcess = new KProcess(this);
-	workProcess->setOutputChannelMode(KProcess::OnlyStdoutChannel);
-	*workProcess << KGpgSettings::gpgBinaryPath();
-	*workProcess << "--no-secmem-warning" << "--no-greeting" << "--no-tty" << "--status-fd=2";
-	*workProcess << "--photo-viewer" << pgpgoutput << "--edit-key" << keyid << "uid" << uid << "showphoto" << "quit";
+	GPGProc workProcess;
+	workProcess << QLatin1String( "--no-greeting" ) << QLatin1String( "--status-fd=2" );
+        workProcess << QLatin1String( "--photo-viewer" ) << pgpgoutput << QLatin1String( "--edit-key" ) << keyid << QLatin1String( "uid" ) << uid << QLatin1String( "showphoto" ) << QLatin1String( "quit" );
 
-	if (!block)
-		connect(workProcess, SIGNAL(finished(int)), SLOT(loadPhotoFin(int)));
-	workProcess->start();
-	if (!block) {
+	workProcess.start();
+	workProcess.waitForFinished();
+	if (workProcess.exitCode() != 0)
 		return QPixmap();
-	} else {
-		workProcess->waitForFinished();
-		if (workProcess->exitCode() == 0)
-			readPixmapFromProcess(workProcess);
-		delete workProcess;
-		return m_pixmap;
-	}
-}
 
-void KgpgInterface::loadPhotoFin(int exitCode)
-{
-	m_pixmap = QPixmap();
+	QString tmpfile;
+	if (workProcess.readln(tmpfile) < 0)
+		return QPixmap();
 
-	if (exitCode == 0) {
-		readPixmapFromProcess(qobject_cast<KProcess *>(sender()));
-	}
-
-	sender()->deleteLater();
-
-	emit loadPhotoFinished(m_pixmap);
-}
-
-void KgpgInterface::readPixmapFromProcess(KProcess *proc)
-{
-	QByteArray pic(proc->readAllStandardOutput());
-
-	while (pic.endsWith('\r') || pic.endsWith('\n'))
-		pic.chop(1);
-
-	KUrl url(pic);
-	m_pixmap.load(url.path());
+	KUrl url(tmpfile);
+	QPixmap pixmap;
+	pixmap.load(url.path());
 	QFile::remove(url.path());
 	QDir dir;
 	dir.rmdir(url.directory());
+
+	return pixmap;
 }
 
 #include "kgpginterface.moc"
