@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007,2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2007,2008,2009,2010 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -50,27 +50,11 @@ signals:
      */
     void verifyfinished();
 
-    /**
-     *  emitted when a txt decryption finished. returns decrypted text
-     */
-    void txtDecryptionFinished(QByteArray);
-
-    /**
-     *  emitted when a txt decryption failed. returns log output
-     */
-    void txtDecryptionFailed(QString);
-
     void txtSigningFinished(QString);
-    void txtSigningFailed(QString);
 
     void txtVerifyMissingSignature(QString);
     void txtVerifyFinished(QString, QString);
 
-    /**
-     *  emitted when the process starts
-     */
-    void processstarted(QString);
-
     /**
      *  emitted when an error occurred
      */
@@ -110,13 +94,6 @@ public Q_SLOTS:
      */
     void encryptText(const QString &text, const QStringList &userids, const QStringList &options = QStringList());
 
-    /**
-     * Decrypt text function
-     * @param text text to be decrypted.
-     * @param options additional gpg options.
-     */
-    void decryptText(const QString &text, const QStringList &options = QStringList());
-
     /**
      * Sign text function
      * @param text text to sign.
@@ -168,10 +145,6 @@ private Q_SLOTS:
     void encryptTextProcess();
     void encryptTextFin();
 
-    void decryptTextStdOut();
-    void decryptTextStdErr();
-    void decryptTextFin();
-
     /**
      * Reads output of the current process + allow overwriting of a file
      */
